// java wrapper for vtkPolarAxesActor object
//

package vtk;
import vtk.*;

public class vtkPolarAxesActor extends vtkActor
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int RenderOpaqueGeometry_2(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_2(id0); }

  private native int RenderOverlay_3(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_3(id0); }

  private native int RenderTranslucentPolygonalGeometry_4(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_4(id0); }

  private native void SetPole_5(double id0[]);
  public void SetPole(double id0[])
    { SetPole_5(id0); }

  private native void SetPole_6(double id0,double id1,double id2);
  public void SetPole(double id0,double id1,double id2)
    { SetPole_6(id0,id1,id2); }

  private native double[] GetPole_7();
  public double[] GetPole()
    { return GetPole_7(); }

  private native void SetLog_8(boolean id0);
  public void SetLog(boolean id0)
    { SetLog_8(id0); }

  private native boolean GetLog_9();
  public boolean GetLog()
    { return GetLog_9(); }

  private native void LogOn_10();
  public void LogOn()
    { LogOn_10(); }

  private native void LogOff_11();
  public void LogOff()
    { LogOff_11(); }

  private native void SetRequestedNumberOfRadialAxes_12(int id0);
  public void SetRequestedNumberOfRadialAxes(int id0)
    { SetRequestedNumberOfRadialAxes_12(id0); }

  private native int GetRequestedNumberOfRadialAxesMinValue_13();
  public int GetRequestedNumberOfRadialAxesMinValue()
    { return GetRequestedNumberOfRadialAxesMinValue_13(); }

  private native int GetRequestedNumberOfRadialAxesMaxValue_14();
  public int GetRequestedNumberOfRadialAxesMaxValue()
    { return GetRequestedNumberOfRadialAxesMaxValue_14(); }

  private native int GetRequestedNumberOfRadialAxes_15();
  public int GetRequestedNumberOfRadialAxes()
    { return GetRequestedNumberOfRadialAxes_15(); }

  private native void SetNumberOfPolarAxisTicks_16(int id0);
  public void SetNumberOfPolarAxisTicks(int id0)
    { SetNumberOfPolarAxisTicks_16(id0); }

  private native int GetNumberOfPolarAxisTicks_17();
  public int GetNumberOfPolarAxisTicks()
    { return GetNumberOfPolarAxisTicks_17(); }

  private native void SetAutoSubdividePolarAxis_18(boolean id0);
  public void SetAutoSubdividePolarAxis(boolean id0)
    { SetAutoSubdividePolarAxis_18(id0); }

  private native boolean GetAutoSubdividePolarAxis_19();
  public boolean GetAutoSubdividePolarAxis()
    { return GetAutoSubdividePolarAxis_19(); }

  private native void AutoSubdividePolarAxisOn_20();
  public void AutoSubdividePolarAxisOn()
    { AutoSubdividePolarAxisOn_20(); }

  private native void AutoSubdividePolarAxisOff_21();
  public void AutoSubdividePolarAxisOff()
    { AutoSubdividePolarAxisOff_21(); }

  private native void SetRange_22(double id0,double id1);
  public void SetRange(double id0,double id1)
    { SetRange_22(id0,id1); }

  private native void SetRange_23(double id0[]);
  public void SetRange(double id0[])
    { SetRange_23(id0); }

  private native double[] GetRange_24();
  public double[] GetRange()
    { return GetRange_24(); }

  private native void SetMinimumRadius_25(double id0);
  public void SetMinimumRadius(double id0)
    { SetMinimumRadius_25(id0); }

  private native double GetMinimumRadius_26();
  public double GetMinimumRadius()
    { return GetMinimumRadius_26(); }

  private native void SetMaximumRadius_27(double id0);
  public void SetMaximumRadius(double id0)
    { SetMaximumRadius_27(id0); }

  private native double GetMaximumRadius_28();
  public double GetMaximumRadius()
    { return GetMaximumRadius_28(); }

  private native void SetMinimumAngle_29(double id0);
  public void SetMinimumAngle(double id0)
    { SetMinimumAngle_29(id0); }

  private native double GetMinimumAngle_30();
  public double GetMinimumAngle()
    { return GetMinimumAngle_30(); }

  private native void SetMaximumAngle_31(double id0);
  public void SetMaximumAngle(double id0)
    { SetMaximumAngle_31(id0); }

  private native double GetMaximumAngle_32();
  public double GetMaximumAngle()
    { return GetMaximumAngle_32(); }

  private native void SetSmallestVisiblePolarAngle_33(double id0);
  public void SetSmallestVisiblePolarAngle(double id0)
    { SetSmallestVisiblePolarAngle_33(id0); }

  private native double GetSmallestVisiblePolarAngleMinValue_34();
  public double GetSmallestVisiblePolarAngleMinValue()
    { return GetSmallestVisiblePolarAngleMinValue_34(); }

  private native double GetSmallestVisiblePolarAngleMaxValue_35();
  public double GetSmallestVisiblePolarAngleMaxValue()
    { return GetSmallestVisiblePolarAngleMaxValue_35(); }

  private native double GetSmallestVisiblePolarAngle_36();
  public double GetSmallestVisiblePolarAngle()
    { return GetSmallestVisiblePolarAngle_36(); }

  private native void SetTickLocation_37(int id0);
  public void SetTickLocation(int id0)
    { SetTickLocation_37(id0); }

  private native int GetTickLocationMinValue_38();
  public int GetTickLocationMinValue()
    { return GetTickLocationMinValue_38(); }

  private native int GetTickLocationMaxValue_39();
  public int GetTickLocationMaxValue()
    { return GetTickLocationMaxValue_39(); }

  private native int GetTickLocation_40();
  public int GetTickLocation()
    { return GetTickLocation_40(); }

  private native void SetRadialUnits_41(boolean id0);
  public void SetRadialUnits(boolean id0)
    { SetRadialUnits_41(id0); }

  private native boolean GetRadialUnits_42();
  public boolean GetRadialUnits()
    { return GetRadialUnits_42(); }

  private native void SetScreenSize_43(double id0);
  public void SetScreenSize(double id0)
    { SetScreenSize_43(id0); }

  private native double GetScreenSize_44();
  public double GetScreenSize()
    { return GetScreenSize_44(); }

  private native void SetCamera_45(vtkCamera id0);
  public void SetCamera(vtkCamera id0)
    { SetCamera_45(id0); }

  private native long GetCamera_46();
  public vtkCamera GetCamera() {
    long temp = GetCamera_46();

    if (temp == 0) return null;
    return (vtkCamera)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetPolarAxisTitle_47(String id0);
  public void SetPolarAxisTitle(String id0)
    { SetPolarAxisTitle_47(id0); }

  private native String GetPolarAxisTitle_48();
  public String GetPolarAxisTitle()
    { return GetPolarAxisTitle_48(); }

  private native void SetPolarLabelFormat_49(String id0);
  public void SetPolarLabelFormat(String id0)
    { SetPolarLabelFormat_49(id0); }

  private native String GetPolarLabelFormat_50();
  public String GetPolarLabelFormat()
    { return GetPolarLabelFormat_50(); }

  private native void SetExponentLocation_51(int id0);
  public void SetExponentLocation(int id0)
    { SetExponentLocation_51(id0); }

  private native int GetExponentLocationMinValue_52();
  public int GetExponentLocationMinValue()
    { return GetExponentLocationMinValue_52(); }

  private native int GetExponentLocationMaxValue_53();
  public int GetExponentLocationMaxValue()
    { return GetExponentLocationMaxValue_53(); }

  private native int GetExponentLocation_54();
  public int GetExponentLocation()
    { return GetExponentLocation_54(); }

  private native void SetRadialAngleFormat_55(String id0);
  public void SetRadialAngleFormat(String id0)
    { SetRadialAngleFormat_55(id0); }

  private native String GetRadialAngleFormat_56();
  public String GetRadialAngleFormat()
    { return GetRadialAngleFormat_56(); }

  private native void ReleaseGraphicsResources_57(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_57(id0); }

  private native void SetEnableDistanceLOD_58(int id0);
  public void SetEnableDistanceLOD(int id0)
    { SetEnableDistanceLOD_58(id0); }

  private native int GetEnableDistanceLOD_59();
  public int GetEnableDistanceLOD()
    { return GetEnableDistanceLOD_59(); }

  private native void SetDistanceLODThreshold_60(double id0);
  public void SetDistanceLODThreshold(double id0)
    { SetDistanceLODThreshold_60(id0); }

  private native double GetDistanceLODThresholdMinValue_61();
  public double GetDistanceLODThresholdMinValue()
    { return GetDistanceLODThresholdMinValue_61(); }

  private native double GetDistanceLODThresholdMaxValue_62();
  public double GetDistanceLODThresholdMaxValue()
    { return GetDistanceLODThresholdMaxValue_62(); }

  private native double GetDistanceLODThreshold_63();
  public double GetDistanceLODThreshold()
    { return GetDistanceLODThreshold_63(); }

  private native void SetEnableViewAngleLOD_64(int id0);
  public void SetEnableViewAngleLOD(int id0)
    { SetEnableViewAngleLOD_64(id0); }

  private native int GetEnableViewAngleLOD_65();
  public int GetEnableViewAngleLOD()
    { return GetEnableViewAngleLOD_65(); }

  private native void SetViewAngleLODThreshold_66(double id0);
  public void SetViewAngleLODThreshold(double id0)
    { SetViewAngleLODThreshold_66(id0); }

  private native double GetViewAngleLODThresholdMinValue_67();
  public double GetViewAngleLODThresholdMinValue()
    { return GetViewAngleLODThresholdMinValue_67(); }

  private native double GetViewAngleLODThresholdMaxValue_68();
  public double GetViewAngleLODThresholdMaxValue()
    { return GetViewAngleLODThresholdMaxValue_68(); }

  private native double GetViewAngleLODThreshold_69();
  public double GetViewAngleLODThreshold()
    { return GetViewAngleLODThreshold_69(); }

  private native void SetPolarAxisVisibility_70(int id0);
  public void SetPolarAxisVisibility(int id0)
    { SetPolarAxisVisibility_70(id0); }

  private native int GetPolarAxisVisibility_71();
  public int GetPolarAxisVisibility()
    { return GetPolarAxisVisibility_71(); }

  private native void PolarAxisVisibilityOn_72();
  public void PolarAxisVisibilityOn()
    { PolarAxisVisibilityOn_72(); }

  private native void PolarAxisVisibilityOff_73();
  public void PolarAxisVisibilityOff()
    { PolarAxisVisibilityOff_73(); }

  private native void SetDrawRadialGridlines_74(int id0);
  public void SetDrawRadialGridlines(int id0)
    { SetDrawRadialGridlines_74(id0); }

  private native int GetDrawRadialGridlines_75();
  public int GetDrawRadialGridlines()
    { return GetDrawRadialGridlines_75(); }

  private native void DrawRadialGridlinesOn_76();
  public void DrawRadialGridlinesOn()
    { DrawRadialGridlinesOn_76(); }

  private native void DrawRadialGridlinesOff_77();
  public void DrawRadialGridlinesOff()
    { DrawRadialGridlinesOff_77(); }

  private native void SetDrawPolarArcsGridlines_78(int id0);
  public void SetDrawPolarArcsGridlines(int id0)
    { SetDrawPolarArcsGridlines_78(id0); }

  private native int GetDrawPolarArcsGridlines_79();
  public int GetDrawPolarArcsGridlines()
    { return GetDrawPolarArcsGridlines_79(); }

  private native void DrawPolarArcsGridlinesOn_80();
  public void DrawPolarArcsGridlinesOn()
    { DrawPolarArcsGridlinesOn_80(); }

  private native void DrawPolarArcsGridlinesOff_81();
  public void DrawPolarArcsGridlinesOff()
    { DrawPolarArcsGridlinesOff_81(); }

  private native void SetPolarTitleVisibility_82(int id0);
  public void SetPolarTitleVisibility(int id0)
    { SetPolarTitleVisibility_82(id0); }

  private native int GetPolarTitleVisibility_83();
  public int GetPolarTitleVisibility()
    { return GetPolarTitleVisibility_83(); }

  private native void PolarTitleVisibilityOn_84();
  public void PolarTitleVisibilityOn()
    { PolarTitleVisibilityOn_84(); }

  private native void PolarTitleVisibilityOff_85();
  public void PolarTitleVisibilityOff()
    { PolarTitleVisibilityOff_85(); }

  private native void SetRadialAxisTitleLocation_86(int id0);
  public void SetRadialAxisTitleLocation(int id0)
    { SetRadialAxisTitleLocation_86(id0); }

  private native int GetRadialAxisTitleLocationMinValue_87();
  public int GetRadialAxisTitleLocationMinValue()
    { return GetRadialAxisTitleLocationMinValue_87(); }

  private native int GetRadialAxisTitleLocationMaxValue_88();
  public int GetRadialAxisTitleLocationMaxValue()
    { return GetRadialAxisTitleLocationMaxValue_88(); }

  private native int GetRadialAxisTitleLocation_89();
  public int GetRadialAxisTitleLocation()
    { return GetRadialAxisTitleLocation_89(); }

  private native void SetPolarAxisTitleLocation_90(int id0);
  public void SetPolarAxisTitleLocation(int id0)
    { SetPolarAxisTitleLocation_90(id0); }

  private native int GetPolarAxisTitleLocationMinValue_91();
  public int GetPolarAxisTitleLocationMinValue()
    { return GetPolarAxisTitleLocationMinValue_91(); }

  private native int GetPolarAxisTitleLocationMaxValue_92();
  public int GetPolarAxisTitleLocationMaxValue()
    { return GetPolarAxisTitleLocationMaxValue_92(); }

  private native int GetPolarAxisTitleLocation_93();
  public int GetPolarAxisTitleLocation()
    { return GetPolarAxisTitleLocation_93(); }

  private native void SetPolarLabelVisibility_94(int id0);
  public void SetPolarLabelVisibility(int id0)
    { SetPolarLabelVisibility_94(id0); }

  private native int GetPolarLabelVisibility_95();
  public int GetPolarLabelVisibility()
    { return GetPolarLabelVisibility_95(); }

  private native void PolarLabelVisibilityOn_96();
  public void PolarLabelVisibilityOn()
    { PolarLabelVisibilityOn_96(); }

  private native void PolarLabelVisibilityOff_97();
  public void PolarLabelVisibilityOff()
    { PolarLabelVisibilityOff_97(); }

  private native void SetArcTicksOriginToPolarAxis_98(int id0);
  public void SetArcTicksOriginToPolarAxis(int id0)
    { SetArcTicksOriginToPolarAxis_98(id0); }

  private native int GetArcTicksOriginToPolarAxis_99();
  public int GetArcTicksOriginToPolarAxis()
    { return GetArcTicksOriginToPolarAxis_99(); }

  private native void ArcTicksOriginToPolarAxisOn_100();
  public void ArcTicksOriginToPolarAxisOn()
    { ArcTicksOriginToPolarAxisOn_100(); }

  private native void ArcTicksOriginToPolarAxisOff_101();
  public void ArcTicksOriginToPolarAxisOff()
    { ArcTicksOriginToPolarAxisOff_101(); }

  private native void SetRadialAxesOriginToPolarAxis_102(int id0);
  public void SetRadialAxesOriginToPolarAxis(int id0)
    { SetRadialAxesOriginToPolarAxis_102(id0); }

  private native int GetRadialAxesOriginToPolarAxis_103();
  public int GetRadialAxesOriginToPolarAxis()
    { return GetRadialAxesOriginToPolarAxis_103(); }

  private native void RadialAxesOriginToPolarAxisOn_104();
  public void RadialAxesOriginToPolarAxisOn()
    { RadialAxesOriginToPolarAxisOn_104(); }

  private native void RadialAxesOriginToPolarAxisOff_105();
  public void RadialAxesOriginToPolarAxisOff()
    { RadialAxesOriginToPolarAxisOff_105(); }

  private native void SetPolarTickVisibility_106(int id0);
  public void SetPolarTickVisibility(int id0)
    { SetPolarTickVisibility_106(id0); }

  private native int GetPolarTickVisibility_107();
  public int GetPolarTickVisibility()
    { return GetPolarTickVisibility_107(); }

  private native void PolarTickVisibilityOn_108();
  public void PolarTickVisibilityOn()
    { PolarTickVisibilityOn_108(); }

  private native void PolarTickVisibilityOff_109();
  public void PolarTickVisibilityOff()
    { PolarTickVisibilityOff_109(); }

  private native void SetAxisTickVisibility_110(int id0);
  public void SetAxisTickVisibility(int id0)
    { SetAxisTickVisibility_110(id0); }

  private native int GetAxisTickVisibility_111();
  public int GetAxisTickVisibility()
    { return GetAxisTickVisibility_111(); }

  private native void AxisTickVisibilityOn_112();
  public void AxisTickVisibilityOn()
    { AxisTickVisibilityOn_112(); }

  private native void AxisTickVisibilityOff_113();
  public void AxisTickVisibilityOff()
    { AxisTickVisibilityOff_113(); }

  private native void SetAxisMinorTickVisibility_114(int id0);
  public void SetAxisMinorTickVisibility(int id0)
    { SetAxisMinorTickVisibility_114(id0); }

  private native int GetAxisMinorTickVisibility_115();
  public int GetAxisMinorTickVisibility()
    { return GetAxisMinorTickVisibility_115(); }

  private native void AxisMinorTickVisibilityOn_116();
  public void AxisMinorTickVisibilityOn()
    { AxisMinorTickVisibilityOn_116(); }

  private native void AxisMinorTickVisibilityOff_117();
  public void AxisMinorTickVisibilityOff()
    { AxisMinorTickVisibilityOff_117(); }

  private native void SetArcTickVisibility_118(int id0);
  public void SetArcTickVisibility(int id0)
    { SetArcTickVisibility_118(id0); }

  private native int GetArcTickVisibility_119();
  public int GetArcTickVisibility()
    { return GetArcTickVisibility_119(); }

  private native void ArcTickVisibilityOn_120();
  public void ArcTickVisibilityOn()
    { ArcTickVisibilityOn_120(); }

  private native void ArcTickVisibilityOff_121();
  public void ArcTickVisibilityOff()
    { ArcTickVisibilityOff_121(); }

  private native void SetArcMinorTickVisibility_122(int id0);
  public void SetArcMinorTickVisibility(int id0)
    { SetArcMinorTickVisibility_122(id0); }

  private native int GetArcMinorTickVisibility_123();
  public int GetArcMinorTickVisibility()
    { return GetArcMinorTickVisibility_123(); }

  private native void ArcMinorTickVisibilityOn_124();
  public void ArcMinorTickVisibilityOn()
    { ArcMinorTickVisibilityOn_124(); }

  private native void ArcMinorTickVisibilityOff_125();
  public void ArcMinorTickVisibilityOff()
    { ArcMinorTickVisibilityOff_125(); }

  private native void SetArcMajorTickSize_126(double id0);
  public void SetArcMajorTickSize(double id0)
    { SetArcMajorTickSize_126(id0); }

  private native double GetArcMajorTickSize_127();
  public double GetArcMajorTickSize()
    { return GetArcMajorTickSize_127(); }

  private native void SetPolarAxisMajorTickSize_128(double id0);
  public void SetPolarAxisMajorTickSize(double id0)
    { SetPolarAxisMajorTickSize_128(id0); }

  private native double GetPolarAxisMajorTickSize_129();
  public double GetPolarAxisMajorTickSize()
    { return GetPolarAxisMajorTickSize_129(); }

  private native void SetLastRadialAxisMajorTickSize_130(double id0);
  public void SetLastRadialAxisMajorTickSize(double id0)
    { SetLastRadialAxisMajorTickSize_130(id0); }

  private native double GetLastRadialAxisMajorTickSize_131();
  public double GetLastRadialAxisMajorTickSize()
    { return GetLastRadialAxisMajorTickSize_131(); }

  private native void SetPolarAxisTickRatioSize_132(double id0);
  public void SetPolarAxisTickRatioSize(double id0)
    { SetPolarAxisTickRatioSize_132(id0); }

  private native double GetPolarAxisTickRatioSize_133();
  public double GetPolarAxisTickRatioSize()
    { return GetPolarAxisTickRatioSize_133(); }

  private native void SetLastAxisTickRatioSize_134(double id0);
  public void SetLastAxisTickRatioSize(double id0)
    { SetLastAxisTickRatioSize_134(id0); }

  private native double GetLastAxisTickRatioSize_135();
  public double GetLastAxisTickRatioSize()
    { return GetLastAxisTickRatioSize_135(); }

  private native void SetArcTickRatioSize_136(double id0);
  public void SetArcTickRatioSize(double id0)
    { SetArcTickRatioSize_136(id0); }

  private native double GetArcTickRatioSize_137();
  public double GetArcTickRatioSize()
    { return GetArcTickRatioSize_137(); }

  private native void SetPolarAxisMajorTickThickness_138(double id0);
  public void SetPolarAxisMajorTickThickness(double id0)
    { SetPolarAxisMajorTickThickness_138(id0); }

  private native double GetPolarAxisMajorTickThickness_139();
  public double GetPolarAxisMajorTickThickness()
    { return GetPolarAxisMajorTickThickness_139(); }

  private native void SetLastRadialAxisMajorTickThickness_140(double id0);
  public void SetLastRadialAxisMajorTickThickness(double id0)
    { SetLastRadialAxisMajorTickThickness_140(id0); }

  private native double GetLastRadialAxisMajorTickThickness_141();
  public double GetLastRadialAxisMajorTickThickness()
    { return GetLastRadialAxisMajorTickThickness_141(); }

  private native void SetArcMajorTickThickness_142(double id0);
  public void SetArcMajorTickThickness(double id0)
    { SetArcMajorTickThickness_142(id0); }

  private native double GetArcMajorTickThickness_143();
  public double GetArcMajorTickThickness()
    { return GetArcMajorTickThickness_143(); }

  private native void SetPolarAxisTickRatioThickness_144(double id0);
  public void SetPolarAxisTickRatioThickness(double id0)
    { SetPolarAxisTickRatioThickness_144(id0); }

  private native double GetPolarAxisTickRatioThickness_145();
  public double GetPolarAxisTickRatioThickness()
    { return GetPolarAxisTickRatioThickness_145(); }

  private native void SetLastAxisTickRatioThickness_146(double id0);
  public void SetLastAxisTickRatioThickness(double id0)
    { SetLastAxisTickRatioThickness_146(id0); }

  private native double GetLastAxisTickRatioThickness_147();
  public double GetLastAxisTickRatioThickness()
    { return GetLastAxisTickRatioThickness_147(); }

  private native void SetArcTickRatioThickness_148(double id0);
  public void SetArcTickRatioThickness(double id0)
    { SetArcTickRatioThickness_148(id0); }

  private native double GetArcTickRatioThickness_149();
  public double GetArcTickRatioThickness()
    { return GetArcTickRatioThickness_149(); }

  private native void SetDeltaRangeMajor_150(double id0);
  public void SetDeltaRangeMajor(double id0)
    { SetDeltaRangeMajor_150(id0); }

  private native double GetDeltaRangeMajor_151();
  public double GetDeltaRangeMajor()
    { return GetDeltaRangeMajor_151(); }

  private native void SetDeltaRangeMinor_152(double id0);
  public void SetDeltaRangeMinor(double id0)
    { SetDeltaRangeMinor_152(id0); }

  private native double GetDeltaRangeMinor_153();
  public double GetDeltaRangeMinor()
    { return GetDeltaRangeMinor_153(); }

  private native void SetDeltaAngleMajor_154(double id0);
  public void SetDeltaAngleMajor(double id0)
    { SetDeltaAngleMajor_154(id0); }

  private native double GetDeltaAngleMajor_155();
  public double GetDeltaAngleMajor()
    { return GetDeltaAngleMajor_155(); }

  private native void SetDeltaAngleMinor_156(double id0);
  public void SetDeltaAngleMinor(double id0)
    { SetDeltaAngleMinor_156(id0); }

  private native double GetDeltaAngleMinor_157();
  public double GetDeltaAngleMinor()
    { return GetDeltaAngleMinor_157(); }

  private native void SetDeltaAngleRadialAxes_158(double id0);
  public void SetDeltaAngleRadialAxes(double id0)
    { SetDeltaAngleRadialAxes_158(id0); }

  private native double GetDeltaAngleRadialAxes_159();
  public double GetDeltaAngleRadialAxes()
    { return GetDeltaAngleRadialAxes_159(); }

  private native void SetRadialAxesVisibility_160(int id0);
  public void SetRadialAxesVisibility(int id0)
    { SetRadialAxesVisibility_160(id0); }

  private native int GetRadialAxesVisibility_161();
  public int GetRadialAxesVisibility()
    { return GetRadialAxesVisibility_161(); }

  private native void RadialAxesVisibilityOn_162();
  public void RadialAxesVisibilityOn()
    { RadialAxesVisibilityOn_162(); }

  private native void RadialAxesVisibilityOff_163();
  public void RadialAxesVisibilityOff()
    { RadialAxesVisibilityOff_163(); }

  private native void SetRadialTitleVisibility_164(int id0);
  public void SetRadialTitleVisibility(int id0)
    { SetRadialTitleVisibility_164(id0); }

  private native int GetRadialTitleVisibility_165();
  public int GetRadialTitleVisibility()
    { return GetRadialTitleVisibility_165(); }

  private native void RadialTitleVisibilityOn_166();
  public void RadialTitleVisibilityOn()
    { RadialTitleVisibilityOn_166(); }

  private native void RadialTitleVisibilityOff_167();
  public void RadialTitleVisibilityOff()
    { RadialTitleVisibilityOff_167(); }

  private native void SetPolarArcsVisibility_168(int id0);
  public void SetPolarArcsVisibility(int id0)
    { SetPolarArcsVisibility_168(id0); }

  private native int GetPolarArcsVisibility_169();
  public int GetPolarArcsVisibility()
    { return GetPolarArcsVisibility_169(); }

  private native void PolarArcsVisibilityOn_170();
  public void PolarArcsVisibilityOn()
    { PolarArcsVisibilityOn_170(); }

  private native void PolarArcsVisibilityOff_171();
  public void PolarArcsVisibilityOff()
    { PolarArcsVisibilityOff_171(); }

  private native void SetUse2DMode_172(int id0);
  public void SetUse2DMode(int id0)
    { SetUse2DMode_172(id0); }

  private native int GetUse2DMode_173();
  public int GetUse2DMode()
    { return GetUse2DMode_173(); }

  private native void SetPolarAxisTitleTextProperty_174(vtkTextProperty id0);
  public void SetPolarAxisTitleTextProperty(vtkTextProperty id0)
    { SetPolarAxisTitleTextProperty_174(id0); }

  private native long GetPolarAxisTitleTextProperty_175();
  public vtkTextProperty GetPolarAxisTitleTextProperty() {
    long temp = GetPolarAxisTitleTextProperty_175();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetPolarAxisLabelTextProperty_176(vtkTextProperty id0);
  public void SetPolarAxisLabelTextProperty(vtkTextProperty id0)
    { SetPolarAxisLabelTextProperty_176(id0); }

  private native long GetPolarAxisLabelTextProperty_177();
  public vtkTextProperty GetPolarAxisLabelTextProperty() {
    long temp = GetPolarAxisLabelTextProperty_177();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetLastRadialAxisTextProperty_178(vtkTextProperty id0);
  public void SetLastRadialAxisTextProperty(vtkTextProperty id0)
    { SetLastRadialAxisTextProperty_178(id0); }

  private native long GetLastRadialAxisTextProperty_179();
  public vtkTextProperty GetLastRadialAxisTextProperty() {
    long temp = GetLastRadialAxisTextProperty_179();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetSecondaryRadialAxesTextProperty_180(vtkTextProperty id0);
  public void SetSecondaryRadialAxesTextProperty(vtkTextProperty id0)
    { SetSecondaryRadialAxesTextProperty_180(id0); }

  private native long GetSecondaryRadialAxesTextProperty_181();
  public vtkTextProperty GetSecondaryRadialAxesTextProperty() {
    long temp = GetSecondaryRadialAxesTextProperty_181();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetPolarAxisProperty_182(vtkProperty id0);
  public void SetPolarAxisProperty(vtkProperty id0)
    { SetPolarAxisProperty_182(id0); }

  private native long GetPolarAxisProperty_183();
  public vtkProperty GetPolarAxisProperty() {
    long temp = GetPolarAxisProperty_183();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetLastRadialAxisProperty_184(vtkProperty id0);
  public void SetLastRadialAxisProperty(vtkProperty id0)
    { SetLastRadialAxisProperty_184(id0); }

  private native long GetLastRadialAxisProperty_185();
  public vtkProperty GetLastRadialAxisProperty() {
    long temp = GetLastRadialAxisProperty_185();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetSecondaryRadialAxesProperty_186(vtkProperty id0);
  public void SetSecondaryRadialAxesProperty(vtkProperty id0)
    { SetSecondaryRadialAxesProperty_186(id0); }

  private native long GetSecondaryRadialAxesProperty_187();
  public vtkProperty GetSecondaryRadialAxesProperty() {
    long temp = GetSecondaryRadialAxesProperty_187();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetPolarArcsProperty_188(vtkProperty id0);
  public void SetPolarArcsProperty(vtkProperty id0)
    { SetPolarArcsProperty_188(id0); }

  private native long GetPolarArcsProperty_189();
  public vtkProperty GetPolarArcsProperty() {
    long temp = GetPolarArcsProperty_189();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetSecondaryPolarArcsProperty_190(vtkProperty id0);
  public void SetSecondaryPolarArcsProperty(vtkProperty id0)
    { SetSecondaryPolarArcsProperty_190(id0); }

  private native long GetSecondaryPolarArcsProperty_191();
  public vtkProperty GetSecondaryPolarArcsProperty() {
    long temp = GetSecondaryPolarArcsProperty_191();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetBounds_192(double id0,double id1,double id2,double id3,double id4,double id5);
  public void SetBounds(double id0,double id1,double id2,double id3,double id4,double id5)
    { SetBounds_192(id0,id1,id2,id3,id4,id5); }

  private native void SetBounds_193(double id0[]);
  public void SetBounds(double id0[])
    { SetBounds_193(id0); }

  private native void GetBounds_194(double id0[]);
  public void GetBounds(double id0[])
    { GetBounds_194(id0); }

  private native void SetRatio_195(double id0);
  public void SetRatio(double id0)
    { SetRatio_195(id0); }

  private native double GetRatioMinValue_196();
  public double GetRatioMinValue()
    { return GetRatioMinValue_196(); }

  private native double GetRatioMaxValue_197();
  public double GetRatioMaxValue()
    { return GetRatioMaxValue_197(); }

  private native double GetRatio_198();
  public double GetRatio()
    { return GetRatio_198(); }

  public vtkPolarAxesActor() { super(); }

  public vtkPolarAxesActor(long id) { super(id); }
  public native long   VTKInit();

}
